OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "You bookmarked \"%s\"" : "Вы создали закладку \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s создал закладку \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Кто-то создал закладку \"%s\"",
    "You deleted \"%s\"" : "Вы удалили \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s удалена \"%2$s\"",
    "Someone deleted \"%s\"" : "Кто-то удалил \"%s\"",
    "You created folder \"%s\"" : "Вы создали папку \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s создал папку \"%2$s\"",
    "Someone created folder \"%s\"" : "Кто-то создал папку \"%s\"",
    "You moved folder \"%s\"" : "Вы переместили папку \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s переместил папку \"%2$s\"",
    "Someone moved folder \"%s\"" : "Кто-то переместил папку \"%s\"",
    "You deleted folder \"%s\"" : "Вы удалили папку \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s удалил папку \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Кто-то удалил папку \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Вы открыли доступ к папке \"%1$s\" для %2$s",
    "You shared folder \"%s\" with someone" : "Вы открыли доступ к папке \"%s\" для всех",
    "%1$s shared folder \"%2$s\" with you" : "%1$s открыл доступ к папке \"%2$s\" для вас",
    "Someone shared folder \"%s\" with you" : "Кто-то открыл доступ к папке \"%s\" для вас",
    "You unshared folder \"%1$s\" with %2$s" : "Вы закрыли доступ к папке \"%1$s\" для %2$s",
    "You unshared folder \"%s\" with someone" : "Вы закрыли доступ к папке \"%s\" для всех",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s закрыл доступ к папке \"%2$s\" для вас",
    "Someone unshared folder \"%s\" with you" : "Кто-то закрыл доступ к папке \"%s\" для вас",
    "No file provided for import" : "Не указан файл для импорта",
    "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
    "Bookmarks shared by %s" : "Закладки предоставлены пользователем %s ",
    "Frequent bookmarks" : "Частые закладки",
    "Recent bookmarks" : "Последние закладки",
    "Bookmark" : "Закладка",
    "Bookmark deleted" : "Закладка удалена",
    "Bookmark created" : "Закладка создана",
    "Bookmark moved" : "Закладка перенесена",
    "Bookmark updated" : "Закладка обновлена",
    "Create bookmark" : "Создать закладку",
    "Takes a link and adds it to your collection of bookmarks." : "Берет ссылку и добавляет ее в Вашу коллекцию закладок.",
    "A Bookmark manager for Nextcloud" : "Менеджер закладок для Nextcloud",
    "Enter new title" : "Введите новый заголовок",
    "Select bookmark" : "Выберите закладки",
    "Details" : "Подробнее",
    "Rename" : "Переименовать",
    "Move" : "Переместить",
    "Add to folders" : "Добавить в папки",
    "Delete" : "Удалить",
    "Do you really want to delete this bookmark?" : "Действительно удалить эту закладку?",
    "Content pending" : "Содержание на ожидании",
    "This content is being downloaded for offline use. Please check back later." : "Этот контент загружается для использования в автономном режиме. Пожалуйста, зайдите позже.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "При сохранении ссылок на фотографии, PDF-файлы и т.д., сами файлы также будут автоматически сохраняться в Nextcloud. Поэтому Вы всегда сможете найти их, даже если ссылка не работает.",
    "Open all selected" : "Открыть выбранные",
    "Move selection" : "Переместить выбранное",
    "Edit tags of selection" : "Редактировать теги выделенного",
    "Delete selection" : "Удалить выбранное",
    "Select all" : "Выбрать все",
    "Cancel selection" : "Отменить выбор",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Выделено {folders} папок и {bookmarks} закладок",
    "Do you really want to delete these items?" : "Действительно удалить выбранные объекты?",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Выделена %n закладка","Выделено %n закладок","Выделено %n закладок","Выделено %n закладок"],
    "_Selected %n folder_::_Selected %n folders_" : ["Выделена %n папка","Выделено %n папок","Выделено %n папок","Выделено %n папок"],
    "Go back" : "Назад",
    "Share folder" : "Поделиться папкой",
    "Select one or more tags" : "Выберите одну или больше меток",
    "New" : "Новая",
    "New bookmark" : "Новая закладка",
    "New folder" : "Новая папка",
    "Change to grid view" : "Перейти в режим просмотра сеткой",
    "Change to list view" : "Перейти в режим просмотра списком",
    "Copy RSS Feed of current view" : "Скопировать RSS-канал текущего просмотра",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-канал требует аутентификации с вашими учётными данными Nextcloud.",
    "Sort by created date" : "Сортировать по дате создания",
    "Sort by last modified" : "Сортировать по дате изменения",
    "Sort by title" : "Сортировать по названию",
    "Sort by click count" : "Сортировать по количеству кликов",
    "Sort by manual order" : "Сортировать по порядку вручную",
    "RSS feed copied" : "RSS-лента скопирована",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Добавление %n закладки в новую папку","Добавление %n закладки в новую папку","Добавление %n закладок в новую папку","Добавление %n закладок в новую папку"],
    "Enter a link" : "Введите ссылку",
    "Enter a title" : "Введите заголовок",
    "No bookmarks found" : "Закладки не найдены",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} папок и {bookmarks} закладок",
    "_%n bookmark_::_%n bookmarks_" : ["%n закладка","%n закладки","%n закладок","%n закладок"],
    "_%n folder_::_%n folders_" : ["%n папка","%n папки","%n папок","%n папок"],
    "Add a bookmark" : "Добавить закладку",
    "Import bookmarks" : "Импорт закладок",
    "Sync with your browser" : "Синхронизация с вашим браузером",
    "Select folder" : "Выделить папку",
    "Enter folder title" : "Введите название папки",
    "Shared by {user}" : "Опубликовано пользователем {user} ",
    "Rename folder" : "Переименовать папку",
    "Move folder" : "Переместить папку",
    "Delete folder" : "Удалить папку",
    "Do you really want to delete this folder?" : "Действительно удалить эту папку?",
    "Choose folder" : "Выберите папку",
    "Submit" : "Создать",
    "Cancel" : "Отмена",
    "Deleting bookmarks" : "Удаление закладок",
    "Deleting selection" : "Удаление выделенного",
    "Importing bookmarks" : "Импорт закладок",
    "Moving selection" : "Перемещение выделенного",
    "Adding selection to folders" : "Добавление выбора к папкам",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Перемещаем %n папку и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки"],
    "_Moving %n folder_::_Moving %n folders_" : ["Перемещаем %n папку","Перемещаем %n папок","Перемещаем %n папок","Перемещаем %n папок"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Перемещаем %n закладку","Перемещаем %n закладок","Перемещаем %n закладок","Перемещаем %n закладок"],
    "All bookmarks" : "Все закладки",
    "Recent" : "Недавние",
    "Shared with you" : "Поделился с вами",
    "Files" : "Файлы",
    "Broken links" : "Нерабочие ссылки",
    "New tag" : "Новый тег",
    "Search tags" : "Поиск по меткам",
    "Untagged" : "Без меток",
    "{used} bookmarks of {available} available" : "{used} закладок из {available} возможных",
    "No bookmarked files" : "Нет файлов в закладках",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "При сохранении ссылок на фотографии, PDF-файлы и т.д., сами файлы также будут автоматически сохраняться в Nextcloud. Поэтому Вы всегда будете иметь к ним доступ, даже если ссылка не работает.",
    "No bookmarks here" : "Здесь нет закладок",
    "Import" : "Импортировать",
    "Export" : "Экспортировать",
    "Archive path" : "Путь к архиву",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Введите путь к папке в ваших файлах, где должны храниться файлы с закладками.",
    "Client apps" : "Клиентские приложения",
    "Also check out the collection of client apps that integrate with this app: " : "Так же попробуйте коллекцию клиентских приложений, которые могут интегрировать с этим приложением",
    "Install web app on device" : "Установите веб-приложение на устройство",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Вы можете установить это приложение на главном экране вашего устройства для быстрого доступа к закладкам на телефоне. Вы можете легко удалить приложение с главного экрана, если оно вам не нравится.",
    "Install on home screen" : "Установить на главную страницу",
    "Bookmarklet" : "Приложение для панели закладок",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Перетащите её в закладки браузера и нажмите на неё, чтобы быстро добавить веб-страницу в закладки.",
    "Add to {instanceName}" : "Добавить в {instanceName}",
    "Please select \"Add to home screen\" in your browser menu" : "Пожалуйста, выберите \"Добавить на главную страницу\" в меню Вашего браузера",
    "Title" : "Название",
    "Link" : "Ссылка",
    "Untitled folder" : "Папка без названия",
    "Root folder" : "Корневая папка",
    "Tags" : "Метки",
    "Select tags and create new ones" : "Выбрать метки и создать новую",
    "Notes" : "Заметки",
    "Notes for this bookmark …" : "Примечания к закладкам...",
    "Archived file" : "Архивный файл",
    "Open file" : "Открыть файл",
    "Open file location" : "Открыть расположение файла",
    "Projects" : "Проекты",
    "Created {time} ago" : "Время создания: {time}",
    "Created on {date}" : "Дата создания: {date}",
    "Owner" : "Владелец",
    "Sharing" : "Общий доступ",
    "Select a user or group" : "Выберите пользователя или группу",
    "Share link" : "Предоставление общего доступа по ссылке",
    "Reading allowed" : "Чтение разрешено",
    "Copy link" : "Скопировать ссылку",
    "Copy RSS feed" : "Скопировать RSS-ленту",
    "Delete link" : "Удалить ссылку",
    "Create public link" : "Создать общедоступную ссылку",
    "Resharing allowed" : "Повторная публикация разрешена",
    "Editing allowed" : "Редактирование разрешено",
    "Allow editing" : "Разрешить редактирование",
    "Allow resharing" : "Разрешить повторную публикацию",
    "Remove share" : "Закрыть общий доступ",
    "Link copied" : "Ссылка скопирована",
    "Privacy" : "Приватность",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bookmarks будет пытаться получить доступ к веб-страницам, которые вы добавили, чтобы автоматически добавить информацию о них.",
    "Enable accessing and collecting information from the web pages you add" : "Включить доступ и сбор информации с веб-страниц, добавляемых вами",
    "Performance" : "Производительность",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "При установке с большим числом пользователей может оказаться полезным ограничение количества закладок на одну учетную запись",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимально допустимое количество закладок для аккаунта (0 для безлимита, он же по-умолчанию)",
    "Previews" : "Предварительный просмотр",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Для того, чтобы показать реальный вид сайтов в ваших закладках, приложение \"Закладки\" может использовать сторонние сервисы для создания изображения",
    "Screeenly" : "Screenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можете либо зарегистрироваться бесплатно на screeenly.com или настроить свой сервер.",
    "Screeenly API URL" : "Ссылка на Screenly API",
    "Screeenly API key" : "API-ключ Screeenly",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "Не удалось сохранить настройки",
    "Failed to load settings" : "Не удалось загрузить настройки",
    "This URL is already bookmarked! Overwrite?" : "Эта ссылка уже в закладках! Перезаписать?",
    "Enter bookmark title" : "Введите заголовок закладки",
    "Enter bookmark URL" : "Введите URL закладки",
    "Folder" : "Каталог",
    "Root Folder" : "Корневая папка",
    "Save" : "Сохранить",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "По умолчанию доступ к сети отключен. Перейдите в настройки администратора для приложения закладок, чтобы разрешить получение превью и значков.",
    "Failed to count unavailable bookmarks" : "Не удалось определить число недоступных закладок",
    "Failed to count archived bookmarks" : "Не удалось определить число архивных закладок",
    "Failed to load bookmark" : "Не удалось загрузить закладку",
    "Failed to find existing bookmark" : "Не удалось найти существующую закладку",
    "Failed to create bookmark" : "Не удалось создать закладку",
    "Failed to save bookmark" : "Не удалось сохранить закладку",
    "Failed to move bookmark" : "Не удалось переместить закладку",
    "Failed to copy bookmark" : "Не удалось скопировать закладку",
    "Failed to delete bookmark" : "Не удалось удалить закладку",
    "Failed to rename tag" : "Не удалось переименовать закладку",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to load folders" : "Не удалось загрузить папки",
    "Failed to delete folder" : "Не удалось удалить папку",
    "Failed to create folder" : "Не удалось создать папку",
    "Failed to fetch bookmarks." : "Не удалось извлечь закладки.",
    "Failed to change setting" : "Не удалось изменить настройки",
    "Failed to load setting {key}" : "Не удалось загрузить настройку {key}",
    "Failed to update share {shareId}" : "Не удалось обновить общий ресурс {shareId}",
    "Failed to delete share {shareId}" : "Не удалось удалить общий ресурс {shareId}",
    "Bookmarks feed" : "Лента закладок"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
